package Qt::Gui::QTapAndHoldGesture;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QTapAndHoldGesture
# file     : QtGui/qgesture.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QGesture/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QTapAndHoldGesture

=head1 PUBLIC METHODS

=over

=item   QTapAndHoldGesture(QObject * parent)

=item   QTapAndHoldGesture(QObject * parent = 0)

=item  QPointF position()

=item  void setPosition(const QPointF & pos)

=item  static void setTimeout(int msecs)

=item  static int timeout()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
